<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=hac
// ** ne pas modifier le fichier **

return [

	// A
	'avis_echec_syndication_01' => 'ارتباط با سايتهاى ديگر برقرار نشد : يا فايل بك اند نا خوانا ست يا هيچ مقاله اى ندارد',
	'avis_echec_syndication_02' => 'ارتباط با سايتهاى ديگر برقرار نشد : دسترسى به بك اند در اين سايت ممكن نميباشد       ',

	// F
	'form_prop_nom_site' => 'نام سايت',

	// I
	'info_a_valider' => '[معتبر شود]',
	'info_bloquer_lien' => 'اين پيوند را مسدود كنيد',
	'info_panne_site_syndique' => 'سايت پيوندى خراب است',
	'info_probleme_grave' => 'نقص در',
	'info_retablir_lien' => 'اين پيوند را دوباره برقرار كنيد',
	'info_site_attente' => 'سايت در انتظار تائيد',
	'info_site_reference' => 'سايت مرجع روى خط ',
	'info_site_refuse' => 'سايت پذيرفته نشده',
	'info_sites_referencer' => 'ارجاع يك سايت',
	'info_syndication' => ':هامبەشکەردەی',
	'info_syndication_articles' => 'بابەت(ی)',
];
